==> zio-aws-amplifybackend_2.13-5.17.122.1-sources.jar: zio/aws/amplifybackend/model/GetBackendAuthRequest.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetBackendAuthRequest(
    appId: __string,
    backendEnvironmentName: __string,
    resourceName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.GetBackendAuthRequest = {
    import GetBackendAuthRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.GetBackendAuthRequest
      .builder()
      .appId(__string.unwrap(appId): java.lang.String)
      .backendEnvironmentName(
        __string.unwrap(backendEnvironmentName): java.lang.String
      )
      .resourceName(__string.unwrap(resourceName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.amplifybackend.model.GetBackendAuthRequest.ReadOnly =
    zio.aws.amplifybackend.model.GetBackendAuthRequest.wrap(buildAwsValue())
}
object GetBackendAuthRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.GetBackendAuthRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.GetBackendAuthRequest =
      zio.aws.amplifybackend.model
        .GetBackendAuthRequest(appId, backendEnvironmentName, resourceName)
    def appId: __string
    def backendEnvironmentName: __string
    def resourceName: __string
    def getAppId: ZIO[Any, Nothing, __string] = ZIO.succeed(appId)
    def getBackendEnvironmentName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(backendEnvironmentName)
    def getResourceName: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.GetBackendAuthRequest
  ) extends zio.aws.amplifybackend.model.GetBackendAuthRequest.ReadOnly {
    override val appId: __string =
      zio.aws.amplifybackend.model.primitives.__string(impl.appId())
    override val backendEnvironmentName: __string =
      zio.aws.amplifybackend.model.primitives
        .__string(impl.backendEnvironmentName())
    override val resourceName: __string =
      zio.aws.amplifybackend.model.primitives.__string(impl.resourceName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.GetBackendAuthRequest
  ): zio.aws.amplifybackend.model.GetBackendAuthRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-amplifybackend_2.13-5.20.22.1-sources.jar: zio/aws/amplifybackend/model/GetBackendAuthRequest.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetBackendAuthRequest(
    appId: __string,
    backendEnvironmentName: __string,
    resourceName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.GetBackendAuthRequest = {
    import GetBackendAuthRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.GetBackendAuthRequest
      .builder()
      .appId(appId: java.lang.String)
      .backendEnvironmentName(backendEnvironmentName: java.lang.String)
      .resourceName(resourceName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.amplifybackend.model.GetBackendAuthRequest.ReadOnly =
    zio.aws.amplifybackend.model.GetBackendAuthRequest.wrap(buildAwsValue())
}
object GetBackendAuthRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.GetBackendAuthRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.GetBackendAuthRequest =
      zio.aws.amplifybackend.model
        .GetBackendAuthRequest(appId, backendEnvironmentName, resourceName)
    def appId: __string
    def backendEnvironmentName: __string
    def resourceName: __string
    def getAppId: ZIO[Any, Nothing, __string] = ZIO.succeed(appId)
    def getBackendEnvironmentName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(backendEnvironmentName)
    def getResourceName: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.GetBackendAuthRequest
  ) extends zio.aws.amplifybackend.model.GetBackendAuthRequest.ReadOnly {
    override val appId: __string = impl.appId(): __string
    override val backendEnvironmentName: __string =
      impl.backendEnvironmentName(): __string
    override val resourceName: __string = impl.resourceName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.GetBackendAuthRequest
  ): zio.aws.amplifybackend.model.GetBackendAuthRequest.ReadOnly = new Wrapper(
    impl
  )
}
